@@ -29,12 +29,14 @@
 #include <NetworkManagerQt/WirelessDevice>
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Setting>
+#include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/ConnectionSettings>
 #include <NetworkManagerQt/GsmSetting>
 #include <NetworkManagerQt/WiredSetting>
 #include <NetworkManagerQt/WirelessSetting>
 #include <NetworkManagerQt/ActiveConnection>
+#include <NetworkManagerQt/Ipv4Setting>
 
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/Manager>
@@ -459,7 +461,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
                 notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
                 break;
             case Handler::RequestScan:
-                /* INFO: Disabled for now as wifi scanning is now automatical
+                /* INFO: Disabled for now as wifi scanning is now automatic
                     notification = new KNotification("FailedToRequestScan", KNotification::CloseOnTimeout, this);
                     notification->setTitle(i18n("Failed to request scan"));
                 */
@@ -518,3 +520,4 @@ void Handler::unlockRequiredChanged(MMModemLock modemLock)
     }
 }
 #endif
+
